<?PHP // $Id$



$string['addcomment'] = ' ';
$string['addentry'] = ' ׸ ';
$string['addingcomment'] = ' ';
$string['aliases'] = '˻';
$string['allcategories'] = ' ';
$string['allentries'] = 'ü';
$string['allowcomments'] = ' ';
$string['allowduplicatedentries'] = ' ';
$string['allowprintview'] = '̸';
$string['allowratings'] = 'õ ';
$string['answer'] = '';
$string['approve'] = '';
$string['areyousuredelete'] = ' ׸ ?';
$string['areyousuredeletecomment'] = '  ?';
$string['areyousureexport'] = '?';
$string['ascending'] = '';
$string['attachment'] = '';
$string['authorview'] = '  ';
$string['back'] = 'ڷ';
$string['cantinsertcat'] = 'ָ ߰  ';
$string['cantinsertrec'] = 'ڷḦ ߰  ';
$string['cantinsertrel'] = ' ׸ 踦   ';
$string['casesensitive'] = '빮, ҹڸ ϼ';
$string['categories'] = ' ׸';
$string['category'] = '';
$string['categorydeleted'] = ' ';
$string['categoryview'] = 'ֺ ';
$string['cnfallowcomments'] = 'ڷ ׸鿡  ޱ  ⺻   ϼ.';
$string['cnfallowdupentries'] = 'ڷ  ׸  ⺻   ϼ.';
$string['cnfapprovalstatus'] = 'л ø  ⺻   ϼ.';
$string['cnfcasesensitive'] = ' ũ ׸ ִٸ ,ҹڸ ϴ  ⺻ ұ?';
$string['cnfdefaulthook'] = 'ڷ ó   ⺻  ׸ ϼ.';
$string['cnfdefaultmode'] = 'ڷ ó   ⺻  ϼ.';
$string['cnffullmatch'] = ' ũ ׸ ִٸ ⺻  ҹڿ ġϵ ұ?';
$string['cnflinkentry'] = '׸ ڵ ũǵ ⺻ ұ?';
$string['cnflinkglossaries'] = 'ڷ ڷ ũǵ ⺻ ұ?';
$string['cnfrelatedview'] = 'ڵ ũ ׸ ⿡ Ǵ ǥ  ϼ.';
$string['cnfshowgroup'] = '׷ ̵ ұ?';
$string['cnfsortkey'] = '⺻  Ű ϼ.';
$string['cnfsortorder'] = '⺻   ϼ.';
$string['cnfstudentcanpost'] = '⺻ л  ø  ֵ ұ, ø   ұ?';
$string['comment'] = '';
$string['commentdeleted'] = ' Ǿϴ.';
$string['comments'] = '';
$string['commentson'] = '';
$string['commentupdated'] = ' ߰Ǿϴ.';
$string['concept'] = '';
$string['concepts'] = '';
$string['configenablerssfeeds'] = '̽ġRss  ּޱ⸦ ϰմϴ.   ּޱ⸦ Ͽ غ    ʿ մϴ.';
$string['currentglossary'] = ' ڷ';
$string['dateview'] = '¥ ';
$string['defaultapproval'] = '  ⺻';
$string['definition'] = '';
$string['definitions'] = '';
$string['deleteentry'] = '׸ ';
$string['deletingcomment'] = ' ';
$string['deletingnoneemptycategory'] = ' ָ ص ֳ ۵  ʽϴ.  ۵   ǥõ Դϴ.';
$string['descending'] = '';
$string['destination'] = '';
$string['displayformat'] = ' ';
$string['displayformatcontinuous'] = 'ø̾ ̾';
$string['displayformatdictionary'] = '  ';
$string['displayformatencyclopedia'] = '';
$string['displayformatentrylist'] = 'Ը';
$string['displayformatfaq'] = '';
$string['displayformatfullwithauthor'] = 'ø̱۷β';
$string['displayformatfullwithoutauthor'] = 'ø̰ƴѱ۷β';
$string['displayformats'] = ' ';
$string['displayformatssetup'] = 'غ';
$string['duplicateentry'] = '׸ ';
$string['editalways'] = '׻ϱ';
$string['editcategories'] = ' ';
$string['editentry'] = '׸ ';
$string['editingcomment'] = ' ';
$string['entbypage'] = 'ʴ ׸';
$string['entries'] = '׸';
$string['entrieswithoutcategory'] = '  ׸';
$string['entry'] = '׸';
$string['entryalreadyexist'] = '̹ ϴ ׸';
$string['entryapproved'] = ' ׸ ε';
$string['entrydeleted'] = '׸ ';
$string['entryexported'] = '׸  ';
$string['entryishidden'] = '( ׸  )';
$string['entryleveldefaultsettings'] = 'Է¼ ʱȭ';
$string['entrysaved'] = 'ԷǾ';
$string['entryupdated'] = 'Է';
$string['entryusedynalink'] = '׸ ڵ ũ';
$string['explainaddentry'] = ' ڷ  ׸ ߰մϴ.';
$string['explainall'] = ' ʿ  ׸ ';
$string['explainalphabet'] = ' Ͽ ڷ ';
$string['explainexport'] = ' Ǿϴ.  ٿ޾ ϰ ϼ. ̰ ٸ Ϳ ٽ   ֽϴ.';
$string['explainimport'] = '   ü  մϴ. ׸  ָ մϴ.';
$string['explainspecial'] = 'ڷ  ʴ ׸ ';
$string['exportedentry'] = ' ׸';
$string['exportedfile'] = ' ';
$string['exportentries'] = '׸ ';
$string['exportglossary'] = 'ڷ ';
$string['exporttomainglossary'] = ' ڷ ';
$string['filetoimport'] = ' ';
$string['fillfields'] = 'ʼ ä־ ϴ ׸';
$string['filtername'] = '۷μ ڵ ũ';
$string['fullmatch'] = ' ġϴ ܾ';
$string['globalglossary'] = 'Ǿֻ';
$string['glossaryleveldefaultsettings'] = 'ּʱ⼳';
$string['glossarytype'] = 'ڷ ';
$string['glosssaryexported'] = 'ڷ ';
$string['importcategories'] = '׸ ';
$string['importedcategories'] = '  ';
$string['importedentries'] = '  ׸';
$string['importentries'] = '׸ ';
$string['isglobal'] = ' ڷ ΰ?';
$string['linkcategory'] = ' ַ ڵ ũ';
$string['mainglossary'] = 'ֵ ڷ';
$string['maxtimehaspassed'] = '˼մϴٸ,   ִ Ƚ($a) ʰϿϴ!';
$string['modulename'] = 'ڷ';
$string['modulenameplural'] = 'ڷ';
$string['newentries'] = 'ο ڷ ׸';
$string['newglossary'] = 'ο ڷ';
$string['newglossarycreated'] = 'ο ڷ ';
$string['newglossaryentries'] = 'ο ڷ ׸:';
$string['nocomment'] = ' ';
$string['nocomments'] = '(۾)';
$string['noconceptfound'] = 'ǵ ';
$string['noentries'] = ' 翡 ߰ߵ ׸ ';
$string['noentry'] = '׸ ';
$string['notcategorised'] = '  ';
$string['numberofentries'] = '׸ ';
$string['onebyline'] = '( ٿ ϳ)';
$string['printerfriendly'] = 'μ ';
$string['printviewnotallowed'] = '¹̸Ⱑ ';
$string['question'] = '';
$string['rate'] = 'õ';
$string['rating'] = 'õϱ';
$string['ratingeveryone'] = ' õ ';
$string['ratingno'] = 'õ ';
$string['ratingonlyteachers'] = ' $a  õ  ';
$string['ratings'] = 'õ';
$string['ratingssaved'] = 'õ ';
$string['ratingsuse'] = 'õ ';
$string['ratingtime'] = 'Ʒ  Ⱓ ׸ õ  ֵ մϴ:';
$string['rejectedentries'] = 'ݼ۵ ׸';
$string['rejectionrpt'] = 'ݼ ';
$string['rsssubscriberss'] = '\'Sa\'RSS մϴ';
$string['searchindefinition'] = ' ˻';
$string['secondaryglossary'] = ' ڷ';
$string['sendinratings'] = ' ֱ õ ּ';
$string['showall'] = '\'\'ũ ';
$string['showalphabet'] = 'öڼ ';
$string['showspecial'] = '\'Ư\' ũ ';
$string['sortby'] = 'з';
$string['sortbycreation'] = ' ';
$string['sortbylastupdate'] = '  ';
$string['sortchronogically'] = 'ǥ  ';
$string['special'] = 'Ư';
$string['standardview'] = ' ';
$string['studentcanpost'] = 'л ׸ ߰  ';
$string['totalentries'] = 'ü ׸';
$string['usedynalink'] = 'ڷ ׸ ڵ ũ';
$string['waitingapproval'] = '  ';
$string['warningstudentcapost'] = '(ڷ  ڷ ƴҶ ϼ)';
$string['withauthor'] = 'ø̻,';
$string['withoutauthor'] = 'ø̻ ';
$string['writtenby'] = 'ø:';
$string['youarenottheauthor'] = '    ĥ  ֽϴ.';
?>
